@@ -6,6 +6,7 @@ from cy_widgets.backtest.strategy import *
 from cy_widgets.backtest.helper import *
 from cy_data_access.models.backtest import *
 from cy_data_access.util.convert import *
+from cy_data_access.connection.connect import *
 from multiprocessing.pool import Pool
 from multiprocessing import Value
 
@@ -18,7 +19,6 @@ class GenericBacktestProcedure:
     start_date = datetime.now()
 
     def __init__(self, task_identifier, time_frames, df, strategy_cls, params, position_func, evaluation_func):
-
         self.__raw_df = df  # 原始 df
         self.__df = df  # 当前回测在用的 df，方便后面加 df 分割和 resample 用
         self.__raw_time_frames = time_frames
@@ -55,6 +55,7 @@ class GenericBacktestProcedure:
             else:
                 param_identifier = context['param_identifier']
                 # 简要数据
+                connect_db_env(db_name=DB_BACKTEST)
                 overview = BacktestOverview(task_identifier=self.__task_identifier,
                                             param_identifier=param_identifier,
                                             equity_curve=evaluated_res.get('累积净值', 0),
@@ -69,11 +70,13 @@ class GenericBacktestProcedure:
     def calculation(self, param):
         """单次回测开始"""
         try:
+            connect_db_env(db_name=DB_BACKTEST)
             strategy = self.__strategy_cls(**param)
             param_str = ";".join(["{}:{}".format(key, param[key]) for key in sorted(param.keys())])
             start_date = dfr.convert_local_date_to_string(self.__df.iloc[0][COL_CANDLE_BEGIN_TIME], "%Y%m%d")
             end_date = dfr.convert_local_date_to_string(self.__df.iloc[-1][COL_CANDLE_BEGIN_TIME], "%Y%m%d")
-            param_identifier = "{}|{}|{}|{}".format(strategy.name, param_str, self.__time_frame, "{},{}".format(start_date, end_date))
+            param_identifier = "{}|{}|{}|{}".format(
+                strategy.name, param_str, self.__time_frame, "{},{}".format(start_date, end_date))
 
             if len(list(BacktestOverview.objects.raw({'task_identifier': self.__task_identifier,
                                                       'param_identifier': param_identifier}))) > 0:
@@ -85,7 +88,8 @@ class GenericBacktestProcedure:
                 'param_identifier': param_identifier
             }
 
-            bt = StrategyBacktest(self.__df.copy(), strategy, self.__position_func, self.__evaluation_func, self.__result_handler, context)
+            bt = StrategyBacktest(self.__df.copy(), strategy, self.__position_func,
+                                  self.__evaluation_func, self.__result_handler, context)
             return bt.perform_test()
         except Exception as e:
             self.unified_exit_handler(False, '回测执行失败', str(param))
